@@ -25,6 +25,8 @@ CDBI Table Class with Enzyme CRUD configuration.
 
 __PACKAGE__->columns(Stringify => "title");
 
+__PACKAGE__->columns(list_columns => qw/ title author genre borrower borrowed format isbn /);
+__PACKAGE__->columns(view_columns => __PACKAGE__->columns("list_columns"), "publisher");
 
 __PACKAGE__->config(
 
